package com.michaelthomas.myjavamail;
import javax.mail.*;
import javax.mail.internet.*;
import java.util.*;


/**
@author Michael Thomas - <a href="mailto:michael@michael-thomas.com">michael@michael-thomas.com</a>
@see JavaMailReceiveEmailPop3_HelloWorld.java
@version 1.0.0
@since 1.0.0

This class is used to send an email with JavaMail using SMTP servers.<br>
This is a "Hello World" type example for text & HTML emails.<br>

Emails:
  * Pass the String "null" if you don't have a CC or BCC
  * You can use comma delimited without spaces for multiple email addresses in the TO, CC, BCC.
  * To send a email alias name use this example for the email String:  "Michael Thomas<michael@michael-thomas.com>"

*/

public class JavaMailSendEmailSmtp {
/**
Main method to send an email from command line arguments.
   
*/
    
  public static void main(String args[]) {
  	
    try {
      String strSMTPServer = args[0];
      String strSMTPPort = args[1];
      String strEmailFROM = args[2];
      String strEmailTO = args[3];
      String strEmailCC = args[4];
      String strEmailBCC = args[5];
      String strEmailSubject = args[6];
      String strEmailBodyText = args[7];
      String strEmailBodyHtml = args[8];

      if ( strEmailCC.equalsIgnoreCase("null") ) {
      	strEmailCC = null;
      }
      if ( strEmailBCC.equalsIgnoreCase("null") ) {
      	strEmailBCC = null;
      }
      if ( strEmailBodyText.equalsIgnoreCase("null") ) {
      	strEmailBodyText = null;
      }
      if ( strEmailBodyHtml.equalsIgnoreCase("null") ) {
      	strEmailBodyHtml = null;
      }
      
      send(strSMTPServer, strSMTPPort, strEmailTO, strEmailFROM, strEmailCC, strEmailBCC, 
           strEmailSubject, strEmailBodyText, strEmailBodyHtml);

    } catch (Exception ex) {
      System.out.println("Error:\n" +
                         "Command Line Usage: java JavaMailSendEmailSmtp" + 
                         " strSMTPServer strSMTPPort strEmailTO strEmailFROM strEmailCC strEmailBCC strEmailSubject strEmailBodyText strEmailBodyHtml" + "\n" +
                         "Java Stack Trace: \n" +
                         "");
       ex.printStackTrace();
    }
    System.exit(0);
  } //main() method

/**
    
"send" method to send the message.

  You may pass multiple email addresses using the "comma" to separate.
  Ex:  "abc@google.com, 123@ibm.com"

    
*/

  public static void send(String strSMTPServer, String strSMTPPort, String strEmailTO, String strEmailFROM, String strEmailCC, String strEmailBCC,
                          String strEmailSubject, String strEmailBodyText, String strEmailBodyHtml) throws Exception {
   	

    String strMsgConsole = ""; 
    
    try {


      if ( true ) {
        strMsgConsole += "*** Debug *** \n" + 
                         "strEmailFROM = " + strEmailFROM + "\n" +
                         "strEmailTO = " + strEmailTO + "\n" +
                         "strEmailCC = " + strEmailCC + "\n" +
                         "strEmailBCC = " + strEmailBCC + "\n" +
                         "strEmailSubject = " + strEmailSubject + "\n" +
                         "";
        System.out.println(strMsgConsole);
        strMsgConsole = "";
      }
    	
      System.out.println("**** Start: Send Test email using JavaMail ****");
      
      //Get/Set the mail.smtp.host Property. Note: I'm not sure how to set the mail.smtp.host value using the OS.
      Properties propSystem = System.getProperties(); //java.util.Properties, java.lang.System
      strMsgConsole += "OS User (" + propSystem.getProperty("user.name") + ") sent email with " + propSystem.getProperty("java.vendor") + " " + propSystem.getProperty("java.version");
      strMsgConsole += "Before: mail.smtp.host = " + propSystem.getProperty("mail.smtp.host") + "\n";
      propSystem.put("mail.smtp.host", strSMTPServer);  
      propSystem.put("mail.smtp.port", strSMTPPort);
      strMsgConsole += "After: mail.smtp.host = " + propSystem.getProperty("mail.smtp.host") + "\n";
      strMsgConsole += "Other props: " + 
                       "mail.store.protocol = " + propSystem.getProperty("mail.store.protocol") + "," +
                       "mail.transport.protocol = " + propSystem.getProperty("mail.transport.protocol") + "," +
                       "mail.host = " + propSystem.getProperty("mail.host") + "," +
                       "mail.user = " + propSystem.getProperty("mail.user") + "," +
                       "mail.from = " + propSystem.getProperty("mail.from") + "," +
                       "\n";

      //Create a JavaMail session (if a default session already exists it will be used otherwise it will create one).
      //This is where all the email config items reside.
      Session session = Session.getDefaultInstance(propSystem, null); //javax.mail.Session
      
      //Create a new email message object. 
      Message msgEmail = new MimeMessage(session); //javax.mail.Message, javax.mail.internet.MimeMessage

      //Set the email properties.
      //*  Email address format info: www.w3.org/Protocols/rfc822/ 

      //Set the email from value.
      msgEmail.setFrom(new InternetAddress(strEmailFROM));

      //Notes:
      //"Michael Thomas" <michael@michael-thomas.com>
      //msgEmail.setFrom(new InternetAddress("\"Michael Thomas\" <michael@michael-thomas.com>")); 
            
      //Set the email to value.
      msgEmail.setRecipients(Message.RecipientType.TO, InternetAddress.parse(strEmailTO, false));
      //msgEmail.setRecipients(Message.RecipientType.TO, InternetAddress.parse("javamail2@michael-thomas.com,javamail1@michael-thomas.com", false));
      
      if (strEmailCC != null) {      
        msgEmail.setRecipients(Message.RecipientType.CC, InternetAddress.parse(strEmailCC, false));
      }

      if (strEmailBCC != null) {      
        msgEmail.setRecipients(Message.RecipientType.BCC, InternetAddress.parse(strEmailBCC, false));
      }

      //Set send date.
      msgEmail.setSentDate(new Date());

      //Set the subject line.
      msgEmail.setSubject(strEmailSubject);
      
      //Set the header info in addition to the BodyPart headers.
      msgEmail.setHeader("X-Mailer", "CustomEmailFromJava"); //in the javax.mail interface called Part

      //***********************************
      //Start: Create the Email Body
      //***********************************
 
      //Step 1: Create an "Alternative" Multipart message
      Multipart mp = new MimeMultipart("alternative");

      //Step 2: Create the Text part of the message.
      if ( strEmailBodyText != null ) {
        MimeBodyPart text = new MimeBodyPart();
        text.setText( strEmailBodyText );
        mp.addBodyPart(text);
      }

      //Step 3: Create the HTML part of the message.
      if ( strEmailBodyHtml != null ) {
        MimeBodyPart html = new MimeBodyPart();
        html.setContent(strEmailBodyHtml, "text/html");
        mp.addBodyPart(html);
      }  

      //Step 4: Set the content for the message.
      msgEmail.setContent(mp);

      //***********************************
      //Stop: Email Body
      //***********************************


      strMsgConsole += "Email Properties (Message object)" + "\n" +
                       "From: " + InternetAddress.toString( msgEmail.getFrom() ) + "\n" +
                       "All recipients: " + InternetAddress.toString( msgEmail.getAllRecipients() ) + "\n" +
                       "Subject line: " + msgEmail.getSubject() + "\n" +
                       "Reply to: " + InternetAddress.toString( msgEmail.getReplyTo() ) + "\n" +
                       "Flags: " + msgEmail.getFlags().toString() + "\n" +
                       "Attempting to send the email ... " + "\n" +
                       "";
      
      System.out.println(strMsgConsole);

      // -- Send the message --
      Transport.send(msgEmail);  // javax.mail.Transport

      strMsgConsole = "";
      strMsgConsole += "Email sent from: " + InternetAddress.toString( msgEmail.getReplyTo() ) + "\n";
      strMsgConsole += "Email sent to (all): " + InternetAddress.toString( msgEmail.getAllRecipients() ) + "\n";
      System.out.println(strMsgConsole);
      System.out.println("**** Stop: Send Test email using JavaMail ****");

    } catch (Exception excEmail) {
      throw excEmail;
    }
  } //send() method
} //class
                    